@@ -1,7 +1,7 @@
 
 package PRANG::Graph::Meta::Element;
-BEGIN {
-  $PRANG::Graph::Meta::Element::VERSION = '0.14';
+{
+  $PRANG::Graph::Meta::Element::VERSION = '0.15';
 }
 
 use Moose::Role;
@@ -188,7 +188,7 @@ sub build_graph_node {
 			push @expect_type, $x->class;
 		}
 		elsif ( $x->isa("Moose::Meta::TypeConstraint::Union") ) {
-			push @st, @{ $x->parents };
+			push @st, @{ $x->type_constraints };
 		}
 		elsif ( $x->isa("Moose::Meta::TypeConstraint::Enum") ) {
 			push @st, $x->parent;
@@ -626,8 +626,8 @@ sub build_graph_node {
 }
 
 package Moose::Meta::Attribute::Custom::Trait::PRANG::Element;
-BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::PRANG::Element::VERSION = '0.14';
+{
+  $Moose::Meta::Attribute::Custom::Trait::PRANG::Element::VERSION = '0.15';
 }
 
 sub register_implementation {
